Monty Python's Flying Circus: Just the Words - Episode 3

# Episode Three: How to recognise different types of trees from quite a long way away

Court scene (witness in coffin/Cardinal Richelieu)
The larch
Bicycle repair man
Children's stories
Restaurant sketch
Seduced milkmen
Stolen newsreader
Children's interview
Nudge nudge

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Opening as usual - man running through a forest towards camera with clothes tattered; arrives at camera, and says:
It's Man | It's...
Voice Over | Monty Python's Flying Circus.
| ANIMATION: Titles sequence as usual. And pretty flowers blooming. This finishes, and a magic lantern slide (done graphically) clicks into vision.
Voice Over | (and CAPTION:) 'EPISODE 12B' 'HOW TO RECOGNISE DIFFERENT TREES FROM QUITE A LONG WAY AWAY' 'NO. 1' 'THE LARCH'
| Photo of a larch tree.
Voice Over | The larch. The larch.
| Courtroom: a judge sitting at higher level and a prisoner in the dock.
Judge | Mr Larch, you heard the case for the prosecution. Is there anything you wish to say before I pass sentence?
Prisoner | Well... I'd just like to say, m'lud, I've got a family... a wife and six kids... and I hope very much you don't have to take away my freedom... because... well, because m'lud freedom is a state much prized within the realm of civilized society. (slips into Olivier impression) It is a bond wherewith the savage man may charm the outward hatchments of his soul, and soothe the troubled breast into a magnitude of quiet. It is most precious as a blessed balm, the saviour of princes, the harbinger of happiness, yea, the very stuff and pith of all we hold most dear. What frees the prisoner in his lonely cell, chained within the bondage of rude walls, far from the owl of Thebes? What fires and stirs the woodcock in his springe or wakes the drowsy apricot betides? What goddess doth the storm toss'd mariner offer her most tempestuous prayers to? Freedom! Freedom! Freedom!
Judge | It's only a bloody parking offence.
| The counsel strides into court.
Counsel | I'm sorry I'm late m'lud I couldn't find a kosher car park. Er... don't bother to recap m'lud, I'll pick it up as we go along. Call Mrs Fiona Lewis.
| A pepperpot walks into the court and gets up into the witness box.
Clerk of the Court | Call Mrs Fiona Lewis.
Pepperpot | (taking bible) I swear to tell the truth, the whole truth and nothing but the truth, so anyway, I said to her, I said, they can't afford that on what he earns, I mean for a start the feathers get up your nose, I ask you, four and six a pound, and him with a wooden leg, I don't know how she puts up with it after all the trouble she's had with her you-know-what, anyway it was a white wedding much to everyone's surprise, of course they bought everything on the hire purchase, I think they ought to send them back where they came from, I mean you've got to be cruel to be kind so Mrs Harris said, so she said, she said, she said, the dead crab she said, she said. Well, her sister's gone to Rhodesia what with her womb and all, and her youngest, her youngest as thin as a filing cabinet, and the goldfish, the goldfish they've got whooping cough they keep spitting water all over their Bratbys, well, they do don't they, I mean you can't, can you, I mean they're not even married or anything, they're not even divorced, and he's in the KGB if you ask me, he says he's a tree surgeon but I don't like the sound of his liver, all that squeaking and banging every night till the small hours, his mother's been much better since she had her head off, yes she has, I said, don't you talk to me about bladders, I said...
| During all this counsel has been trying to ask questions. Eventually he gives up and Mrs. Lewis is pushed out of court still talking.
Judge | Mr Bartlett, I fail to see the relevance of your last witness.
Counsel | My next witness will explain that if m'ludship will allow. I call the late Arthur Aldridge.
Clerk of the Court | The late Arthur Aidridge.
Judge | The late Arthur Aldridge?
Counsel | Yes m'lud.
| A coffin is brought into the court and laid across the witness box.
Judge | Mr Bartlett, do you think there is any relevance in questioning the deceased?
Counsel | I beg your pardon m'lud.
Judge | Well, I mean, your witness is dead.
Counsel | Yes, m'lud. Er, well, er, virtually, m'lud.
Judge | He's not completely dead?
Counsel | No he's not completely dead m'lud. No. But he's not at all well.
Judge | But if he's not dead, what's he doing in a coffin?
Counsel | Oh, it's purely a precaution m'lud - if I may continue? Mr Aldridge, you were a... you are a stockbroker of 10 Savundra Close, Wimbledon. (from the coffin comes a bang) Mr Aldridge...
Judge | What was that knock?
Counsel | It means 'yes' m'lud. One knock for 'yes', and two knocks for 'no'. If I may continue? Mr Aldridge, would it be fair to say that you are not at all well? (from the coffin comes a bang) In fact Mr Aldridge, not to put too fine a point on it, would you be prepared to say that you are, as it were, what is generally known as, in a manner of speaking, 'dead'? (silence, counsel listens;) Mr Aldridge I put it to you that you are dead. (silence) Ah ha!
Judge | Where is all this leading us?
Counsel | That will become apparent in one moment m'lud. (walking over to coffin) Mr Aldridge are you considering the question or are you just dead? (silence) I think I'd better take a look m'lud. (he opens the coffin and looks inside for some time; then he closes the coffin) No further questions m'lud.
Judge | What do you mean, no further questions? You can't just dump a dead body in my court and say 'no further questions'. I demand an explanation.
Counsel | There are no easy answers in this case m'lud.
Judge | I think you haven't got the slightest idea what this case is about.
Counsel | M'lud the strange, damnable, almost diabolic threads of this extraordinary tangled web of intrigue will shortly m'lud reveal a plot so fiendish, so infernal, so heinous ...
Judge | Mr Bartlett, your client has already pleaded guilty to the parking offence.
Counsel | Parking offence, schmarking offence, m'lud. We must leave no stone unturned. Call Cardinal Richelieu.
Judge | Oh, you're just trying to string this case out. Cardinal Richelieu?
Counsel | A character witness m'lud.
| Fanfare of trumpets. Cardinal Richelieu enters witness box in beautiful robes.
Cardinal | 'Allo everyone, it's wonderful to be 'ere y'know, I just love your country. London is so beautiful at this time of year.
Counsel | Er, you are Cardinal Armand du Piessis de Richelieu, First Minister of Louis XIII?
Cardinal | Oui.
Counsel | Cardinal, would it be fair to say that you not only built up the centralized monarchy in France but also perpetuated the religious schism in Europe?
Cardinal | (modestly) That's what they say.
Counsel | Did you persecute the Huguenots?
Cardinal | Oui.
Counsel | And did you take even sterner measures against the great Catholic nobles who made common cause with foreign foes in defence of their feudal independence?
Cardinal | I sure did that thing.
Counsel | Cardinal. Are you acquainted with the defendant, Harold Larch?
Cardinal | Since I was so high (indicated how high).
Counsel | Speaking as a Cardinal of the Roman Catholic Church, as First Minister of Louis XIII, and as one of the architects of the modern world already - would you say that Harold Larch was a man of good character?
Cardinal | Listen. Harry is a very wonderful human being.
Counsel | M'lud. In view of the impeccable nature of this character witness may I plead for clemency.
Judge | Oh but it's only thirty shillings.
| Enter Inspector Dim.
Dim | Not so fast!
Prisoner | Why not?
Dim | (momentarily thrown) None of your smart answers ... you think you're so clever. Well, I'm Dim.
| A caption appears on the screen 'DIM OF THE YARD'
Omnes | (in unison) Dim! Consternation! Uproar!
Dim | Yes, and I've a few questions I'd like to ask Cardinal so-called Richelieu.
Cardinal | Bonjour Monsieur Dim.
Dim | So-called Cardinal, I put it to you that you died in December 1642.
Cardinal | That is correct.
Dim | Ah ha! He fell for my little trap.
| Court applauds and the Cardinal looks dismayed.
Cardinal | Curse you Inspector Dim. You are too clever for us naughty people.
Dim | And furthermore I suggest that you are none other than Ron Higgins, professional Cardinal Richelieu impersonator.
Cardinal | It's a fair cop.
Counsel | My you're clever Dim. He'd certainly taken me in.
Dim | It's all in a day's work.
Judge | With a brilliant mind like yours, Dim, you could be something other than a policeman.
Dim | Yes.
Judge | What?
| Piano starts playing introduction.
Dim | (singing) If I were not in the CID Something else I'd like to be If I were not in the CID A window cleaner, me! With a rub-a-dub-dub and a scrub-a-dub-dub And a rub-a-dub all day long With a rub-a-dub-dub and a scrub-a-dub-dub I'd sing this merry song!
| He mimes window cleaning movements and the rest of the court enthusiastically mimes and sings the chorus again with him. When the chorus verse ends the counsel enthusiastically takes over but this time the court all sit and watch him as though he has gone completely mad.
Counsel | (Singing) If I were not before the bar Something else I'd like to be If I were not a barr-is-ter An engine driver me! With a chuffchuffchuff etc.
| He makes engine miming movements. As before. After a few seconds he sees that the rest of the court are staring at him in amazement and he loses momentum rapidly, almost as rapidly as he loses confidence and dignity. At last he subsides. Our knight in armour walks up to the counsel and hits him with the traditional raw chicken.
Voice Over | (and CAPTION:) 'NO. 1' 'THE LARCH'
| Photo of larch tree.
Voice Over | The larch. The larch.
Voice Over | (and CAPTION:) 'AND NOW...NO. 1...THE LARCH...AND NOW...'
| Superman film: shot from below of Superman (Michael) striding along against the sky.
Commentator | (American accent) This man is no ordinary man. This is Mr. F. G. Superman. To all appearances, he looks like any other law-abiding citizen.
| Pull back to reveal he is in a modern street full of Supermen walking along shopping, waiting at bus queues etc. F. G. Superman gets onto a bus. The bus is full of Supermen, most of them with shopping baskets on their knees. F. G. Supermen finds a seat...during the commentary the camera slowly tracks in on his face.
Commentator | But Mr F. G. Superman has a secret identity...when trouble strikes at any time...at any place...he is ready to become... Bicycle Repair Man!
| The camera is by now in very tight close-up. A country lane. A superman rides into the shot on a bicycle, whistling innocently. Suddenly he veers off to one side and crashes down into a ditch. Cut to a laundrette. Pan along a row of Supermen, one or two of whom are poring over magazines such as: 'The Adventures of an Insurance Broker', 'Income Tax Comics', and 'The Grocer'. Suddenly the door flies open and a youngish Superboy bursts in dramatically.
Superboy | (dramatically) Hey, there's a bicycle broken. Up the road. (he points dramatically)
| General consternation.
Bicycle Repair Man | (voice over) Hmmmmm. Thinks - this sounds like a job for... Bicycle Repair Man...but how to change without revealing my secret identity?
| Close-up F. G. Superman. He narrows his eyes.
First Superman | If only Bicycle Repair Man were here!
F. G. Superman | Yes. Wait! I think I know where I can find him - look over there!
| F. G. Superman points out of window; they turn and look obediently. F. G. Superman whips overall out of case and puts them on. CAPTION: 'FLASH!' Fantastically speeded-up for this. His overalls have 'Bicycle Repair Man' written across the chest. He completes the transformation with a pair of little round specs and a bag of tools. He makes for the door and all the Supermen turn and raise their hands in amazement.
Supermen | Bicycle Repair Man! But...how?!
First Superman | Oh look - is it a Stockbroker?
Second Superman | Is it a Quantity Surveyor?
Third Superman | Is it a Church Warden?
All | No! It's BICYCLE REPAIR MAN!
| Country road. Superman is standing over the mangled bits looking at it and scratching his head. Bicycle Repair Man speeds up to him. Superman stands back in surprise, with arms raised.
Superman | My! BICYCLE REPAIR MAN! Thank goodness you've come! (he points stiltedly) Look!
| Bicycle Repair Man pushes him to one side and kneels beside the broken bicycle. Speeded-up: he mends the bike with spanners etc. Graphics. CAPTIONS: CLINK! SCREW! BEND! INFLATE! ALTER SADDLE! A little group of Supermen has gathered to watch him work. As he does so they point in amazement.
Second Superman | Why! He's mending it with his own hands!
First Superman | See! How he uses a spanner to tighten that nut!
| Cut to Bicycle Repair Man presenting the Superman with a glittering drop-handlebarred bike.
Superman | Oh...Oh! Bicycle Repair Man! How can I ever repay you?
Bicycle Repair Man | Oh, you don't need to guv, it's all right, it's all in a days work for... Bicycle Repair Man! (he shuffles away)
Supermen | Our Hero! (shot of Bicycle Repair Man shuffling, speeded up, into sunset)
Commentator | Yes! Whenever bicycles are broken, or menaced by International Communism, Bicycle Repair Man is ready!
| Cut to commentator in garden with earphones on, and in front of microphone, which is on a garden table.
Commentator | Ready to smash the communists, wipe them up, and shove them off the face of the earth...(his voice rises hysterically) Mash that dirty red scum, kick 'em in the teeth where it hurts. (commentator rises from his canvas chair, and flails about wildly, waving script, kicking over table, knocking down sunshade) Kill! Kill! Kill! The filthy bastard commies, I hate 'em! I hate 'em! Aaargh! Aaargh!
Wife | (off-screen) Norman! Tea's ready.
| He immediately looks frightened, and goes docile.
Commentator | (calmly) Coming dear!
| He gathers up his script, picks up chair, and walks out of frame. Pause, then the man in the suit of armour crosses frame after him.
| ANIMATION: Five seconds of Gilliam animation. To gentle children's programme music, we see bunnies jumping up and down. Cut to children's storyteller in studio.
Storyteller | (sitting with large children's book, at desk) Hello, Children, hello. Here is this morning's story. Are you ready? Then we'll begin. (opens book; reads) 'One day Ricky the magic Pixie went to visit Daisy Bumble in her tumbledown cottage. He found her in the bedroom. Roughly he gabbed her heavy shoulders pulling her down on to the bed and ripping off her...; (reads silently, turns over page quickly, smiles) 'Old Nick the Sea Captain was a rough tough jolly sort of fellow. He loved the life of the sea and he loved to hang out down by the pier where the men dressed as ladies...' (reads on silently; a stick enters vision and pokes him; he starts and turns over page)..... 'Rumpletweezer ran the Dinky Tinky shop in the foot of the magic oak tree by the wobbly dumdum bush in the shade of the magic glade down in Dingly Dell. Here he sold contraceptives and ... discipline?... naked? ... (without looking up, reads a bit; then, incredulously to himself) With a melon!?
| ANIMATION: A hippo squashes the bunnies...and other things happen. Cut to a seaside beach. By a notice, 'Donkey Rides', run two men carrying a donkey. The compère addresses the camera.
Compère | Hello again, now here's a little sketch by two boys from London town. They've been writing for three years and they've called this little number - here it is, it's called - Restaurant sketch.
| Film clip of Women's Institute applauding. A couple are seated at a table in a restaurant.
Lady | It's nice here, isn't it?
Man | Oh, very good restaurant, three stars you know.
Lady | Really?
Man | Mmm...
Waiter | Good evening, sir! Good evening, madam! And may I say what a pleasure it is to see you here again, sir!
Man | Oh thank you. Well there you are dear. Have a look there, anything you like. The boeuf en croute is fantastic.
Waiter | Oh if I may suggest, sir ... the pheasant à la reine, the sauce is one of the chefs most famous creations.
Man | Em... that sounds good. Anyway just have a look... take your time. Oh, er by the way - got a bit of a dirty fork, could you ... er.. get me another one?
Waiter | I beg your pardon.
Man | Oh it's nothing ... er, I've got a fork a little bit dirty. Could you get me another one? Thank you.
Waiter | Oh ... sir, I do apologize.
Man | Oh, no need to apologize, it doesn't worry me.
Waiter | Oh no, no, no, I do apologize. I will fetch the head waiter immediatement.
Man | Oh, there's no need to do that!
Waiter | Oh, no no... I'm sure the head waiter, he will want to apologize to you himself. I will fetch him at once.
Lady | Well, you certainly get good service here.
Man | They really look after you... yes.
Head Waiter | Excuse me monsieur and madame. (examines the fork) It's filthy, Gaston ... find out who washed this up, and give them their cards immediately.
Man | Oh, no, no.
Head Waiter | Better still, we can't afford to take any chances, sack the entire washing-up staff.
Man | No, look I don't want to make any trouble.
Head Waiter | Oh, no please, no trouble. It's quite right that you should point these kind of things out. Gaston, tell the manager what has happened immediately! (The Waiter runs off)
Man | Oh, no I don't want to cause any fuss.
Head Waiter | Please, it's no fuss. I quite simply wish to ensure that nothing interferes with your complete enjoyment of the meal.
Man | Oh I'm sure it won't, it was only a dirty fork.
Head Waiter | I know. And I'm sorry, bitterly sorry, but I know that... no apologies I can make can alter the fact that in our restaurant you have been given a dirty, filthy, smelly piece of cutlery...
Man | It wasn't smelly.
Head Waiter | It was smelly, and obscene and disgusting and I hate it, I hate it ,.. nasty, grubby, dirty, mingy, scrubby little fork. Oh ... oh . . . oh . . . (runs off in a passion as the manager comes to the table)
Manager | Good evening, sir, good evening, madam. I am the manager. I've only just heard . .. may I sit down?
Man | Yes, of course.
Manager | I want to apologize, humbly, deeply, and sincerely about the fork.
Man | Oh please, it's only a tiny bit... I couldn't see it.
Manager | Ah you're good kind fine people, for saying that, but I can see it.., to me it's like a mountain, a vast bowl of pus.
Man | It's not as bad as that.
Manager | It gets me here. I can't give you any excuses for it - there are no excuses. I've been meaning to spend more time in the restaurant recently, but I haven't been too well... (emotionally) things aren't going very well back there. The poor cook's son has been put away again, and poor old Mrs Dalrymple who does the washing up can hardly move her poor fingers, and then there's Gilberto's war wound - but they're good people, and they're kind people, and together we were beginning to get over this dark patch ... there was light at the end of the tunnel . .. now this . .. now this...
Man | Can I get you some water?
Manager | (in tears) It's the end of the road!!
| The cook comes in; he is very big and comes a meat cleaver.
Cook | (shouting) You bastards! You vicious, heartless bastards! Look what you've done to him! He's worked his fingers to the bone to make this place what it is, and you come in with your petty feeble quibbling and you grind him into the dirt, this fine, honourable man, whose boots you are not worthy to kiss. Oh... it makes me mad... mad! (slams cleaver into the table)
| The head waiter comes in and tries to restrain him.
Head Waiter | Easy, Mungo, easy... Mungo... (clutches his head in agony) the war wound!... the wound... the wound...
Manager | This is the end! The end! Aaargh!! (stabs himself with the fork)
Cook | They've destroyed him! He's dead!! They killed him!!! (goes completely mad)
Head Waiter | (trying to restrain him) No Mungo... never kill a customer. (in pain) Oh . .. the wound! The wound! (he and the cook fight furiously and fall over the table)
| CAPTION: 'AND NOW THE PUNCH-LINE'
Man | Lucky we didn't say anything about the dirty knife.
| Boos of disgust from off-screen. Cut back to seaside.
Compère | Well, there we are then, that was the restaurant sketch, a nice little number...a bit vicious in parts, but a lot of fun...but how about that punch line, eh?...Oh, you know what I mean - oh...oh...really.
| The man from the sketch borrows the knight's chicken and hits commentator with it. A cartoon advertising 'Interesting Lives' leads to film of milkman (Michael) delivering milk to a suburban house. As he puts the milk down, the front door opens and a seductively dressed young lady (Carol) beckons him inside. Glancing round furtively he follows her into the house and up the stairs. She leads him to the bedroom door, opens it, and ushers him inside, closing the door behind him. Inside, he is bewildered to see several elderly milkmen, who have obviously been there for a very long time. Cut to BBC News studio, where the newsreader is just putting the phone dovn. At his desk is an old-fashioned microphone with 'BBC' on it. He is in evening dress, and speaks in beautifully modulated tones.
Newsreader | Good evening, here is the 6 o'clock News read by Michael Queen. It's been a quite day over most of the country as people went back to work after the warmest July weekend for nearly a year. The only high spot of the weekend was the meeting between officials of the NEDC and the ODCN in Bradford today.
| At this point, axes split open the studio door behind him. Through the hole, men with stockings over their heads leap in firing guns in all directions. The newsreader continues, unperturbed. Cut to marauders pushing the newsreader, still at his desk down a passage in the BBC. They rush him out of the TV Centre and onto the back of a lorry.
Newsreader | (continuing) In Geneva, officials of the Central Clearing Banks met with Herr Voleschtadt of Poland to discuss non-returnable loans on a twelve-year trust basis for the construction of a new zinc-treating works in the Omsk area of Krakow, near the Bulestan border. The Board of Trade has ratified a Trade Agreement with the Soviet Union for the sale of 600 low gear electric sewing machines. The President of the Board of Trade said he hoped this would mark a new area of expansion in world trade and a new spirit of co-operation between East and West. There has been a substantial drop in Gold Reserves during the last twelve months. This follows a statement by the Treasury to the effect that the balance of imports situation had not changed dramatically over the same period. (cut to lorry hurtling through London with newsreader still reading news on the back (facing backwards); cut to lorry hurtling through country lane and flashing past camera) Still no news of the National Savings book lost by Mr Charles Griffiths of Porthcawl during a field expedition to the Nature Reserves of Swansea last July. Mr Griffiths' wife said that her husband was refusing to talk to the Press until the Savings Certificate had been found. (cut to gang hoisting him on to the back of an open lorry, still in desk etc.) In Cornwall the death has been announced today of the former Minister without Portfolio, General Sir Hugh Marksby-Smith. Sir Hugh was vice-president of the Rotarian movement. (a long shot of a jetty; we see the gang still pushing the newsreader still on his desk along the jetty; they reach the end and push him over into the sea) In the match between Glamorgan and Yorkshire, the Yorkshire bowler Nicholson took eight wickets for three runs. Glareorgan were all out for the thirty-six and therefore won the match by an innings and seven runs. Weather for tomorrow will be cloudy with occasional outbreaks of rain. And that is the end of the news.
| FX splash. Gurgle gurgle.
Voice Over | (and CAPTIONS:) 'AND NOW' 'NO. 1' 'THE LARCH'
| Picture of a larch tree.
Voice Over | The larch
Voice Over | (and CAPTIONS:) 'AND NOW' 'NO. 3' 'THE LARCH' 'AND NOW...'
| Picture of a chestnut tree.
Voice Over | The horse chestnut.
| Film clip of cheering crowd. Then to inteviewer bending down to speak to children in playground.
Interviewer | Eric ... do you think you could recognize a larch tree?
Eric | (after much deliberation) Don't know.
| Roars of delighted pre-recorded laughter from unseen audience.
Interviewer | What's your name?
Michael | Michael.
| Laughter.
Interviewer | Michael, do you think you know what a larch tree looks like?
Michael | (bursting into tears) I want to go home.
| Shrieks from unseen audience.
Terry | Bottom!
| More shrieks.
Interviewer | Are there any other trees that any of you think you could recognize from quite a long way away?
Terry | I ... want... to see a sketch of Eric's please...
Interviewer | What?
Terry | I want to see a sketch of Eric's. Nudge Nudge.
Interviewer | A sketch?
Terry | Eric's written...
Eric | I written a sketch.
Michael | Nudge nudge, Eric's written ...
Eric | Nudge nudge...nudge...nudge.
| Two men in a pub
Norman | Is your wife a...goer...eh? Know what I mean? Know what I mean? Nudge nudge. Nudge nudge. Know what I mean? Say no more...know what I mean?
Him | I beg your pardon?
Norman | Your wife...does she, er, does she 'go' - eh? eh? eh? Know what I mean, know what I mean? Nudge nudge. Say no more.
Him | Well, she sometimes goes, yes.
Norman | I bet she does. I bet she does. I bet she does. Know what I mean? Nudge nudge.
Him | I'm sorry, I don't quite follow you.
Norman | Follow me. Follow me. I like that. That's good. A nod's as good as a wink to a blind bat, eh? (elbow gesture; rubs it)
Him | Are you trying to sell something?
Norman | Selling, selling. Very good. Very good. (hand tilting quickly) Oh, wicked. Wicked. You're wicked. Eh? Know what I mean. Know what I mean? Nudge nudge. Know what I mean? Nudge nudge. Nudge nudge. (leaning over to him, making eye gesture; speaks slowly) Say...no...more. (leans back as if having imparted a great secret)
Him | But...
Norman | (stops him with finger which he lays alongside nose; gives slight tap) Your wife is she, eh... is she a sport. Eh?
Him | She likes sport, yes!
Norman | I bet she does, I bet she does!
Him | She is very fond of cricket, as a matter of fact.
Norman | (leans across, looking away) Who isn't, eh? Know what I mean. Likes games, likes games. Knew she would. Knew she would. Knew she would. Likes games, eh? She's been around, eh? Been around?
Him | She's traveled. She's from Purley.
Norman | Oh...oh. Say no more, say no more. Say no more - Purley, say no more. Purley, eh? Know what I mean, know what I mean. Say no more.
Him | (about to speak; can't think of anything to say)
Norman | (leers, grinning) Your wife interested in er... (waggles head, leans across) photographs, eh? Know what I mean? Photographs, 'he asked him knowingly'.
Him | Photography?
Norman | Yes. Nudge nudge. Snap snap. Grin grin, wink wink, say no more?
Him | Holiday snaps?
Norman | Could be, could be taken on holiday. Could be yes - swimming costumes. Know what I mean. Candid photography. Know what I mean, nudge nudge.
Him | No, no we don't have a camera.
Norman | Oh. Still (slaps hands lightly twice) Woah! Eh? Wo-oah! Eh?
Him | Look, are you insinuating something?
Norman | Oh...no...no... Yes.
Him | Well?
Norman | Well. I mean. Er, I mean. You're a man of the world, aren't you...I mean, er, you've er... you've been there haven't you...I mean you've been around...eh?
Him | What do you mean?
Norman | Well I mean like you've er...you've done it...I mean like, you know...you've...er...you've slept...with a lady.
Him | Yes.
Norman | What's it like?
| Enourmous artificial laugh on sound track. Closing film, starting with referee blowing whistle and then into 'It's' man running away from camera. ROLLER CAPTION: '"HOW TO RECOGNIZE DIFFERENT TYPES OF TREES FROM QUITE A LONG WAY AWAY" WAS CONCIEVED, WRITTEN AND PERFORMED BY...(CREDITS)'
Voice Over | The Larch.